==> DateTime-Locale-1.36.tar.gz: DateTime-Locale-1.36/share/ga.pl <==
{
  am_pm_abbreviated => [
    "r.n.",
    "i.n.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "dd/MM/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "LL",
    MEd => "E dd/MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-few" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-many" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-one" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-other" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-two" => "'seachtain' 'a' W 'i' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E dd/MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'seachtain' 'a' w 'in' Y",
    "yw-count-many" => "'seachtain' 'a' w 'in' Y",
    "yw-count-one" => "'seachtain' 'a' w 'in' Y",
    "yw-count-other" => "'seachtain' 'a' w 'in' Y",
    "yw-count-two" => "'seachtain' 'a' w 'in' Y",
  },
  code => "ga",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Luan",
    "M\N{U+00e1}irt",
    "C\N{U+00e9}ad",
    "D\N{U+00e9}ar",
    "Aoine",
    "Sath",
    "Domh",
  ],
  day_format_narrow => [
    "L",
    "M",
    "C",
    "D",
    "A",
    "S",
    "D",
  ],
  day_format_wide => [
    "D\N{U+00e9} Luain",
    "D\N{U+00e9} M\N{U+00e1}irt",
    "D\N{U+00e9} C\N{U+00e9}adaoin",
    "D\N{U+00e9}ardaoin",
    "D\N{U+00e9} hAoine",
    "D\N{U+00e9} Sathairn",
    "D\N{U+00e9} Domhnaigh",
  ],
  day_stand_alone_abbreviated => [
    "Luan",
    "M\N{U+00e1}irt",
    "C\N{U+00e9}ad",
    "D\N{U+00e9}ar",
    "Aoine",
    "Sath",
    "Domh",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "C",
    "D",
    "A",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "D\N{U+00e9} Luain",
    "D\N{U+00e9} M\N{U+00e1}irt",
    "D\N{U+00e9} C\N{U+00e9}adaoin",
    "D\N{U+00e9}ardaoin",
    "D\N{U+00e9} hAoine",
    "D\N{U+00e9} Sathairn",
    "D\N{U+00e9} Domhnaigh",
  ],
  era_abbreviated => [
    "RC",
    "AD",
  ],
  era_narrow => [
    "RC",
    "AD",
  ],
  era_wide => [
    "Roimh Chr\N{U+00ed}ost",
    "Anno Domini",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Irish",
  month_format_abbreviated => [
    "Ean",
    "Feabh",
    "M\N{U+00e1}rta",
    "Aib",
    "Beal",
    "Meith",
    "I\N{U+00fa}il",
    "L\N{U+00fa}n",
    "MF\N{U+00f3}mh",
    "DF\N{U+00f3}mh",
    "Samh",
    "Noll",
  ],
  month_format_narrow => [
    "E",
    "F",
    "M",
    "A",
    "B",
    "M",
    "I",
    "L",
    "M",
    "D",
    "S",
    "N",
  ],
  month_format_wide => [
    "Ean\N{U+00e1}ir",
    "Feabhra",
    "M\N{U+00e1}rta",
    "Aibre\N{U+00e1}n",
    "Bealtaine",
    "Meitheamh",
    "I\N{U+00fa}il",
    "L\N{U+00fa}nasa",
    "Me\N{U+00e1}n F\N{U+00f3}mhair",
    "Deireadh F\N{U+00f3}mhair",
    "Samhain",
    "Nollaig",
  ],
  month_stand_alone_abbreviated => [
    "Ean",
    "Feabh",
    "M\N{U+00e1}rta",
    "Aib",
    "Beal",
    "Meith",
    "I\N{U+00fa}il",
    "L\N{U+00fa}n",
    "MF\N{U+00f3}mh",
    "DF\N{U+00f3}mh",
    "Samh",
    "Noll",
  ],
  month_stand_alone_narrow => [
    "E",
    "F",
    "M",
    "A",
    "B",
    "M",
    "I",
    "L",
    "M",
    "D",
    "S",
    "N",
  ],
  month_stand_alone_wide => [
    "Ean\N{U+00e1}ir",
    "Feabhra",
    "M\N{U+00e1}rta",
    "Aibre\N{U+00e1}n",
    "Bealtaine",
    "Meitheamh",
    "I\N{U+00fa}il",
    "L\N{U+00fa}nasa",
    "Me\N{U+00e1}n F\N{U+00f3}mhair",
    "Deireadh F\N{U+00f3}mhair",
    "Samhain",
    "Nollaig",
  ],
  name => "Irish",
  native_language => "Gaeilge",
  native_name => "Gaeilge",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+00fa} r\N{U+00e1}ithe",
    "2\N{U+00fa} r\N{U+00e1}ithe",
    "3\N{U+00fa} r\N{U+00e1}ithe",
    "4\N{U+00fa} r\N{U+00e1}ithe",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+00fa} r\N{U+00e1}ithe",
    "2\N{U+00fa} r\N{U+00e1}ithe",
    "3\N{U+00fa} r\N{U+00e1}ithe",
    "4\N{U+00fa} r\N{U+00e1}ithe",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.39.tar.gz: DateTime-Locale-1.39/share/ga.pl <==
{
  am_pm_abbreviated => [
    "r.n.",
    "i.n.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "dd/MM/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "LL",
    MEd => "E dd/MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-few" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-many" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-one" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-other" => "'seachtain' 'a' W 'i' MMMM",
    "MMMMW-count-two" => "'seachtain' 'a' W 'i' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E dd/MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'seachtain' 'a' w 'in' Y",
    "yw-count-many" => "'seachtain' 'a' w 'in' Y",
    "yw-count-one" => "'seachtain' 'a' w 'in' Y",
    "yw-count-other" => "'seachtain' 'a' w 'in' Y",
    "yw-count-two" => "'seachtain' 'a' w 'in' Y",
  },
  code => "ga",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Luan",
    "M\N{U+00e1}irt",
    "C\N{U+00e9}ad",
    "D\N{U+00e9}ar",
    "Aoine",
    "Sath",
    "Domh",
  ],
  day_format_narrow => [
    "L",
    "M",
    "C",
    "D",
    "A",
    "S",
    "D",
  ],
  day_format_wide => [
    "D\N{U+00e9} Luain",
    "D\N{U+00e9} M\N{U+00e1}irt",
    "D\N{U+00e9} C\N{U+00e9}adaoin",
    "D\N{U+00e9}ardaoin",
    "D\N{U+00e9} hAoine",
    "D\N{U+00e9} Sathairn",
    "D\N{U+00e9} Domhnaigh",
  ],
  day_stand_alone_abbreviated => [
    "Luan",
    "M\N{U+00e1}irt",
    "C\N{U+00e9}ad",
    "D\N{U+00e9}ar",
    "Aoine",
    "Sath",
    "Domh",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "C",
    "D",
    "A",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "D\N{U+00e9} Luain",
    "D\N{U+00e9} M\N{U+00e1}irt",
    "D\N{U+00e9} C\N{U+00e9}adaoin",
    "D\N{U+00e9}ardaoin",
    "D\N{U+00e9} hAoine",
    "D\N{U+00e9} Sathairn",
    "D\N{U+00e9} Domhnaigh",
  ],
  era_abbreviated => [
    "RC",
    "AD",
  ],
  era_narrow => [
    "RC",
    "AD",
  ],
  era_wide => [
    "Roimh Chr\N{U+00ed}ost",
    "Anno Domini",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Irish",
  month_format_abbreviated => [
    "Ean",
    "Feabh",
    "M\N{U+00e1}rta",
    "Aib",
    "Beal",
    "Meith",
    "I\N{U+00fa}il",
    "L\N{U+00fa}n",
    "MF\N{U+00f3}mh",
    "DF\N{U+00f3}mh",
    "Samh",
    "Noll",
  ],
  month_format_narrow => [
    "E",
    "F",
    "M",
    "A",
    "B",
    "M",
    "I",
    "L",
    "M",
    "D",
    "S",
    "N",
  ],
  month_format_wide => [
    "Ean\N{U+00e1}ir",
    "Feabhra",
    "M\N{U+00e1}rta",
    "Aibre\N{U+00e1}n",
    "Bealtaine",
    "Meitheamh",
    "I\N{U+00fa}il",
    "L\N{U+00fa}nasa",
    "Me\N{U+00e1}n F\N{U+00f3}mhair",
    "Deireadh F\N{U+00f3}mhair",
    "Samhain",
    "Nollaig",
  ],
  month_stand_alone_abbreviated => [
    "Ean",
    "Feabh",
    "M\N{U+00e1}rta",
    "Aib",
    "Beal",
    "Meith",
    "I\N{U+00fa}il",
    "L\N{U+00fa}n",
    "MF\N{U+00f3}mh",
    "DF\N{U+00f3}mh",
    "Samh",
    "Noll",
  ],
  month_stand_alone_narrow => [
    "E",
    "F",
    "M",
    "A",
    "B",
    "M",
    "I",
    "L",
    "M",
    "D",
    "S",
    "N",
  ],
  month_stand_alone_wide => [
    "Ean\N{U+00e1}ir",
    "Feabhra",
    "M\N{U+00e1}rta",
    "Aibre\N{U+00e1}n",
    "Bealtaine",
    "Meitheamh",
    "I\N{U+00fa}il",
    "L\N{U+00fa}nasa",
    "Me\N{U+00e1}n F\N{U+00f3}mhair",
    "Deireadh F\N{U+00f3}mhair",
    "Samhain",
    "Nollaig",
  ],
  name => "Irish",
  native_language => "Gaeilge",
  native_name => "Gaeilge",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+00fa} r\N{U+00e1}ithe",
    "2\N{U+00fa} r\N{U+00e1}ithe",
    "3\N{U+00fa} r\N{U+00e1}ithe",
    "4\N{U+00fa} r\N{U+00e1}ithe",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+00fa} r\N{U+00e1}ithe",
    "2\N{U+00fa} r\N{U+00e1}ithe",
    "3\N{U+00fa} r\N{U+00e1}ithe",
    "4\N{U+00fa} r\N{U+00e1}ithe",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 43,
}
